---
name: Bug report
about: Create a report to help us improve Judgeval
title: "[BUG]"
labels: potential bug

---

## Describe the bug
A clear and concise description of what the bug is.

## To Reproduce
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

## Expected behavior
A clear and concise description of what you expected to happen.

## Screenshots
If applicable, add screenshots to help explain your problem.

## Environment (please complete the following information):
 - OS: [e.g. MacOS, Linux, Windows]
 - Browser (if website issue): [e.g. Chrome, Safari, Firefox]
 - Browser Version (if website issue): [e.g. 22]
 - SDK Version: [e.g. 1.2.3]
 - Programming Language/Runtime (if SDK issue): [e.g. Python 3.11, Python 3.12, etc.]
 - Package Manager (if SDK issue): [e.g. uv, pip, pipenv]

## Additional context
Add any other context about the problem here.

## Are you interested to contribute a fix for this bug?
If this is a confirmed bug, the Judgment community is happy to support with guidance and review via [Discord](https://discord.com/invite/tGVFf8UBUY).

- [ ] Yes
- [ ] No

